==> gnome-dvb-daemon-0.1.5.tar.bz2: gnome-dvb-daemon-0.1.5/src/Channel.h <==

#ifndef __SRC_CHANNEL_H__
#define __SRC_CHANNEL_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee/list.h>
#include <gst/gst.h>

G_BEGIN_DECLS

typedef struct _DVBChannel DVBChannel;
typedef struct _DVBChannelClass DVBChannelClass;
typedef struct _DVBEventElement DVBEventElement;
typedef struct _DVBEventElementClass DVBEventElementClass;
typedef struct _DVBSchedule DVBSchedule;
typedef struct _DVBScheduleClass DVBScheduleClass;

#define DVB_TYPE_CHANNEL (dvb_channel_get_type ())
#define DVB_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL, DVBChannel))
#define DVB_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL, DVBChannelClass))
#define DVB_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL))
#define DVB_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL))
#define DVB_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL, DVBChannelClass))

typedef struct _DVBChannelPrivate DVBChannelPrivate;

struct _DVBChannel {
	GObject parent_instance;
	DVBChannelPrivate * priv;
};

struct _DVBChannelClass {
	GObjectClass parent_class;
	gboolean (*is_valid) (DVBChannel* self);
	gboolean (*on_same_transport_stream) (DVBChannel* self, DVBChannel* channel);
	void (*setup_dvb_source) (DVBChannel* self, GstElement* source);
	char* (*to_string) (DVBChannel* self);
};


char* dvb_channel_get_audio_pids_string (DVBChannel* self);
gboolean dvb_channel_is_valid (DVBChannel* self);
gboolean dvb_channel_on_same_transport_stream (DVBChannel* self, DVBChannel* channel);
void dvb_channel_setup_dvb_source (DVBChannel* self, GstElement* source);
char* dvb_channel_to_string (DVBChannel* self);
guint dvb_channel_get_Sid (DVBChannel* self);
void dvb_channel_set_Sid (DVBChannel* self, guint value);
const char* dvb_channel_get_Name (DVBChannel* self);
void dvb_channel_set_Name (DVBChannel* self, const char* value);
guint dvb_channel_get_TransportStreamId (DVBChannel* self);
void dvb_channel_set_TransportStreamId (DVBChannel* self, guint value);
const char* dvb_channel_get_Network (DVBChannel* self);
void dvb_channel_set_Network (DVBChannel* self, const char* value);
guint* dvb_channel_get_LogicalChannelNumber (DVBChannel* self);
void dvb_channel_set_LogicalChannelNumber (DVBChannel* self, guint* value);
guint dvb_channel_get_VideoPID (DVBChannel* self);
void dvb_channel_set_VideoPID (DVBChannel* self, guint value);
GeeList* dvb_channel_get_AudioPIDs (DVBChannel* self);
void dvb_channel_set_AudioPIDs (DVBChannel* self, GeeList* value);
guint dvb_channel_get_Frequency (DVBChannel* self);
void dvb_channel_set_Frequency (DVBChannel* self, guint value);
gboolean dvb_channel_get_Scrambled (DVBChannel* self);
void dvb_channel_set_Scrambled (DVBChannel* self, gboolean value);
DVBSchedule* dvb_channel_get_Schedule (DVBChannel* self);
GType dvb_channel_get_type (void);


G_END_DECLS

#endif

==> gnome-dvb-daemon-0.1.7.tar.bz2: gnome-dvb-daemon-0.1.7/src/Channel.h <==
/*
 * Copyright (C) 2008,2009 Sebastian Pölsterl
 *
 * This file is part of GNOME DVB Daemon.
 *
 * GNOME DVB Daemon is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GNOME DVB Daemon is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNOME DVB Daemon.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __SRC_CHANNEL_H__
#define __SRC_CHANNEL_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee/list.h>
#include <gst/gst.h>

G_BEGIN_DECLS

typedef struct _DVBChannel DVBChannel;
typedef struct _DVBChannelClass DVBChannelClass;
typedef struct _DVBEventElement DVBEventElement;
typedef struct _DVBEventElementClass DVBEventElementClass;
typedef struct _DVBSchedule DVBSchedule;
typedef struct _DVBScheduleClass DVBScheduleClass;

#define DVB_TYPE_CHANNEL (dvb_channel_get_type ())
#define DVB_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_CHANNEL, DVBChannel))
#define DVB_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_CHANNEL, DVBChannelClass))
#define DVB_IS_CHANNEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_CHANNEL))
#define DVB_IS_CHANNEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_CHANNEL))
#define DVB_CHANNEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_CHANNEL, DVBChannelClass))

typedef struct _DVBChannelPrivate DVBChannelPrivate;

struct _DVBChannel {
	GObject parent_instance;
	DVBChannelPrivate * priv;
};

struct _DVBChannelClass {
	GObjectClass parent_class;
	gboolean (*is_valid) (DVBChannel* self);
	gboolean (*on_same_transport_stream) (DVBChannel* self, DVBChannel* channel);
	gboolean (*equals) (DVBChannel* self, DVBChannel* channel);
	void (*setup_dvb_source) (DVBChannel* self, GstElement* source);
	char* (*to_string) (DVBChannel* self);
};


char* dvb_channel_get_audio_pids_string (DVBChannel* self);
gboolean dvb_channel_is_valid (DVBChannel* self);
gboolean dvb_channel_on_same_transport_stream (DVBChannel* self, DVBChannel* channel);
gboolean dvb_channel_equals (DVBChannel* self, DVBChannel* channel);
void dvb_channel_setup_dvb_source (DVBChannel* self, GstElement* source);
char* dvb_channel_to_string (DVBChannel* self);
guint dvb_channel_get_Sid (DVBChannel* self);
void dvb_channel_set_Sid (DVBChannel* self, guint value);
guint dvb_channel_get_GroupId (DVBChannel* self);
void dvb_channel_set_GroupId (DVBChannel* self, guint value);
const char* dvb_channel_get_Name (DVBChannel* self);
void dvb_channel_set_Name (DVBChannel* self, const char* value);
guint dvb_channel_get_TransportStreamId (DVBChannel* self);
void dvb_channel_set_TransportStreamId (DVBChannel* self, guint value);
const char* dvb_channel_get_Network (DVBChannel* self);
void dvb_channel_set_Network (DVBChannel* self, const char* value);
guint* dvb_channel_get_LogicalChannelNumber (DVBChannel* self);
void dvb_channel_set_LogicalChannelNumber (DVBChannel* self, guint* value);
guint dvb_channel_get_VideoPID (DVBChannel* self);
void dvb_channel_set_VideoPID (DVBChannel* self, guint value);
GeeList* dvb_channel_get_AudioPIDs (DVBChannel* self);
void dvb_channel_set_AudioPIDs (DVBChannel* self, GeeList* value);
guint dvb_channel_get_Frequency (DVBChannel* self);
void dvb_channel_set_Frequency (DVBChannel* self, guint value);
gboolean dvb_channel_get_Scrambled (DVBChannel* self);
void dvb_channel_set_Scrambled (DVBChannel* self, gboolean value);
DVBSchedule* dvb_channel_get_Schedule (DVBChannel* self);
GType dvb_channel_get_type (void);


G_END_DECLS

#endif
